<?php
/**
 * Class with local functions for Kerio Workspace
 *
 * @copyright	Copyright &copy; 2012-2012 Kerio Technologies s.r.o.
 * @version		1.3.0.62
 */
class WorkspaceClient {

	/**
	 * API handler
	 * @var	resource
	 */
	private $api;

	/**
	 * Construct.
	 * 
	 * @param	object	API object
	 * @return	object	Workspace
	 */
	public function __construct($api) {
		$this->api = $api;
		return $this;
	}

	/**
	 * Create new component.
	 *  
	 * @param	integer	Item ID
	 * @param	string	Item type
	 * @param	string	Item name
	 * @return	integer	Item ID
	 */
	private function create($pid, $type, $name) {
		$params = array(
			'pid' => $pid,
			'type' => $type,
			'name' => $name
		);
		$result = $this->api->sendRequest('CreateItem', $params);
		return $result['item']['id'];
	}

	/**
	 * Create new space.
	 * 
	 * @param	integer	Space ID, set NULL for root space
	 * @param	string	Space name
	 * @return	integer	Space ID
	 */
	public function createSpace($spaceId, $name) {
		return $this->create($spaceId, 'Space', $name);
	}

	/**
	 * Create new page.
	 * 
	 * @param	integer	Space ID
	 * @param	string	Page name
	 * @return	integer	Page ID
	 */
	public function createPage($spaceId, $name) {
		return $this->create($spaceId, 'Page', $name);
	}

	/**
	 * Create new file library.
	 * 
	 * @param	integer	Page ID
	 * @param	string	Title
	 * @return	integer	Item ID
	 */
	public function createFileLibrary($pageId, $title) {
		return $this->create($pageId, 'FileLib', $title);
	}

	/**
	 * Create new text component.
	 * 
	 * @param	integer	Page ID
	 * @param	string	Title
	 * @param	string	Content, can be HTML
	 * @return	integer	Item ID
	 */
	public function createTextNoteComponent($pageId, $title, $content) {
		$id = $this->create($pageId, 'TextNote', $title);
		$params = array(
			'id' => $id,
			'value' => array(
				'text' => $content
			)
		);
		$this->	api->sendRequest('UpdateItem', $params);
	}

	/**
	 * Upload a file to component.
	 * 
	 * @param	integer	Item ID, can be type of Image, FileLib
	 * @param	string	Path to file
	 * @return	integer	Item ID
	 */
	public function upload($itemId, $file) {
		$result = $this->api->uploadFile($file, $itemId);
		return $result['item']['id'];
	}
}

